@@ -12,7 +12,7 @@ class Component:
             for style in style_list.split(";"):
                 styles = style.replace('\n','').split('=')
                 if '=' in style:
-                    self.styles[styles[0]] = styles[1]
+                    self.styles[styles[0]] = styles[1].replace('"', '')
                 else:
                     self.styles['style'] = styles[0]
         
